@@ -1,10 +1,14 @@
 # flake8: noqa
+# type: ignore
 __author__ = "Akio Taniguchi"
-__version__ = "0.2.4"
+__version__ = "0.3.1"
 
 
 # submodules
 from . import article
 from . import apps
+from . import cli
+from . import constants
+from . import detex
 from . import search
 from . import translate
